package com.burtbeckwith.clusterdemo

/**
 * Authority domain class.
 */
class Role implements Serializable {

	private static final long serialVersionUID = 1

	static hasMany = [people: User]

	String description
	String authority

	Date dateCreated

	@Override
	String toString() { authority }

	static constraints = {
		authority blank: false, unique: true
	}

	static mapping = {
		cache usage: 'read-only'
		version false
	}

	static List<Role> list(boolean useCache = true) {
		return withSession { session ->
			session.createQuery('FROM Role').setCacheable(useCache).list()
		}
	}

	static int count(boolean useCache = true) {
		return withSession { session ->
			return session.createQuery('SELECT COUNT(*) FROM Role')
				.setCacheable(useCache)
				.list()[0] + 1
		}
	}
}
